@@ -11,7 +11,11 @@ class TeaException(Exception):
         return f'Error: {self.code} {self.message} Response: {self.data}'
 
 
-class RequiredArgumentException(TeaException):
+class ValidateException(Exception):
+    pass
+
+
+class RequiredArgumentException(ValidateException):
     def __init__(self, arg):
         self.arg = arg
 
@@ -19,7 +23,7 @@ class RequiredArgumentException(TeaException):
         return f'"{self.arg}" is required.'
 
 
-class RetryError(TeaException):
+class RetryError(Exception):
     def __init__(self, message):
         self.message = message
         self.data = None
@@ -29,11 +33,20 @@ class UnretryableException(TeaException):
     def __init__(
             self,
             request: TeaRequest,
-            ex: TeaException
+            ex: Exception
     ):
         self.last_request = request
         self.inner_exception = ex
-        self.message = f"Retry failed: {ex.message}"
+        if isinstance(ex, TeaException):
+            super().__init__({
+                'code': ex.code,
+                'message': ex.message,
+                'data': ex.data
+            })
+        else:
+            super().__init__({
+                'message': repr(ex),
+            })
 
     def __str__(self):
         return str(self.inner_exception)
